@@ -14,19 +14,28 @@ from .base import (
     File,
     basic_call,
 )
+from .statsupdater import StatsUpdater
+from .reactionrolemessages import ReactionRoleMessage
+from .interactions import Interaction, InteractionType
 from .biasgame import BiasGame
+from .eightball import EightBallResponse
+from .urban import Urban
 from .wolfram import Wolfram
 from .date import Date
+from .reminder import Reminder
 from .tag import Tag
 from .groupalias import GroupAlias
 from .personalias import PersonAlias
 from .company import Company
 from .location import Location
 from .bloodtype import BloodType
+from .automedia import AutoMedia, AffiliationTime
 from .position import Position
 from .social import Social
 from .display import Display
 from .fandom import Fandom
+from .banphrase import BanPhrase
+from .notification import Notification
 from .name import Name
 from .group import Group
 from .person import Person
@@ -37,6 +46,7 @@ from .guild import Guild
 from .channel import Channel
 from .language import Language, PackMessage
 from .subscription import Subscription
+from .tiktokaccount import TikTokAccount
 from .twitchaccount import TwitchAccount
 from .twitteraccount import TwitterAccount
 from .preloadcache import Preload
